@@ -25,7 +25,7 @@
 #include "b-complain.h"
 #include "b-divvy.h"
 
-struct divvy *shared;
+struct divvy *plexus;
 struct divvy *single;
 
 static void
@@ -59,7 +59,7 @@ xmalloc (size_t size)
 #define obstack_chunk_free free
 
 struct divvy *
-make_space (const char const name[])
+make_space (char const name[])
 {
   struct divvy *divvy = TCALLOC (struct divvy);
 
@@ -67,7 +67,18 @@ make_space (const char const name[])
   divvy->space = TCALLOC (struct obstack);
   obstack_alloc_failed_handler = oom;
   obstack_init (divvy->space);
-  divvy->first = obstack_next_free ((struct obstack *) divvy->space);
+
+  /* Set alignment to avoid segfault (on some hosts).
+     The downside is wasted space on less-sensitive hosts.  */
+  {
+    size_t widest = sizeof (off_t);
+
+    if (widest < sizeof (void *))
+      widest = sizeof (void *);
+    obstack_alignment_mask (divvy->space) = widest - 1;
+  }
+
+  divvy->first = obstack_next_free (divvy->space);
 #ifdef DEBUG
   complain ("%s: %32s %p\n", name, "first", divvy->first);
 #endif
@@ -88,6 +99,8 @@ alloc (struct divvy *divvy, char const *what USED_FOR_DEBUG, size_t len)
   complain ("%s: %6u  %s\n", divvy->name, len, what);
 #endif
   divvy->count++;
+  /* DWR: The returned memory is uninitialized.
+     If you have doubts, use ‘zlloc’ instead.  */
   return obstack_alloc (divvy->space, len);
 }
 
