@@ -110,13 +110,13 @@ set_uid_to (uid_t u)
   if (! currently_setuid_p ())
     return;
 #if defined HAVE_WORKING_FORK
-#if has_setreuid
+#if defined HAVE_SETREUID
   if (PROB (setreuid (u == euid () ? ruid () : euid (), u)))
     fatal_sys ("setuid");
-#else  /* !has_setreuid */
+#else  /* !defined HAVE_SETREUID */
   if (PROB (seteuid (u)))
     fatal_sys ("setuid");
-#endif  /* !has_setreuid */
+#endif  /* !defined HAVE_SETREUID */
 #endif  /* defined HAVE_WORKING_FORK */
   if (geteuid () != u)
     {
@@ -159,40 +159,37 @@ setrid (void)
 
 char const *
 getusername (bool suspicious)
-/* Get the caller's login name.  Trust only ‘getwpuid’ if ‘suspicious’.  */
+/* Get and return the caller's login name.
+   Trust only ‘getwpuid_r’ if ‘suspicious’.  */
 {
   if (!BE (username))
     {
 #define JAM(x)  (BE (username) = x)
-      if (
-          /* Prefer ‘getenv’ unless ‘suspicious’; it's much faster.  */
-#if getlogin_is_secure
-          (suspicious
-           || (!JAM (cgetenv ("LOGNAME"))
-               && !JAM (cgetenv ("USER")))
-           && !JAM (getlogin ()))
-#else
-          suspicious
-          || (!JAM (cgetenv ("LOGNAME"))
-              && !JAM (getenv ("USER"))
-              && !JAM (getlogin ()))
-#endif
-          )
-        {
-#if defined HAVE_GETUID && defined HAVE_GETPWUID
-          struct passwd const *pw = getpwuid (ruid ());
+      char buf[BUFSIZ];
 
-          if (!pw)
-            PFATAL ("no password entry for userid %lu",
-                    (unsigned long) ruid ());
-          JAM (pw->pw_name);
-#else  /* !(defined HAVE_GETUID && defined HAVE_GETPWUID) */
+      /* Prefer ‘getenv’ unless ‘suspicious’; it's much faster.  */
+      if (suspicious
+          || (!JAM (cgetenv ("LOGNAME"))
+              && !JAM (cgetenv ("USER"))
+              && !(0 == getlogin_r (buf, BUFSIZ)
+                   && JAM (str_save (buf)))))
+        {
+#if !defined HAVE_GETPWUID_R
 #if defined HAVE_SETUID
           PFATAL ("setuid not supported");
 #else
           PFATAL ("Who are you?  Please setenv LOGNAME.");
 #endif
-#endif  /* !(defined HAVE_GETUID && defined HAVE_GETPWUID) */
+#else  /* defined HAVE_GETPWUID_R */
+          struct passwd pwbuf, *pw = NULL;
+
+          if (getpwuid_r (ruid (), &pwbuf, buf, BUFSIZ, &pw)
+              || &pwbuf != pw
+              || !pw->pw_name)
+            PFATAL ("no password entry for userid %d", ruid ());
+
+          JAM (str_save (pw->pw_name));
+#endif  /* defined HAVE_GETPWUID_R */
         }
       checksid (BE (username));
 #undef JAM
