@@ -25,6 +25,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
+#include "unistd-safer.h"
 #include "b-complain.h"
 #include "b-divvy.h"
 #include "b-excwho.h"
@@ -38,51 +39,12 @@
 
 struct ephemstuff
 {
-  char *tmpdir;
+  char const *standard;
   struct sff *tpnames;
 };
 
 #define EPH(x)  (BE (ephemstuff)-> x)
 
-#ifndef HAVE_MKSTEMP
-static int
-homegrown_mkstemp (char *template)
-/* Like mkstemp(2), but never return EINVAL.  That is, never check for
-   missing "XXXXXX" since we know the unique caller DTRT.  */
-{
-  int pid = getpid ();
-  char *end = template + strlen (template);
-  char const xrep[] = {"abcdefghijklmnopqrstuvwxyz"
-                       "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
-                       /* Omit '0' => ‘strlen (xrep)’ is prime.  */
-                       "123456789"};
-  struct timeval tv;
-  uint64_t n;
-  int fd = -1;
-
-  for (int patience = 42 * 42;
-       PROB (fd) && patience;
-       patience--)
-    {
-      if (PROB (gettimeofday (&tv, NULL)))
-        return -1;
-      /* Cast to ensure 64-bit shift.  */
-      n = pid | (uint64_t)(tv.tv_sec ^ tv.tv_usec) << 32;
-      for (char *w = end - 6; n && w < end; w++)
-        {
-          *w = xrep[n % 61];
-          n = n / 61;
-        }
-      fd = open (template, O_RDWR | O_CREAT | O_EXCL, S_IRUSR | S_IWUSR);
-    }
-  if (PROB (fd))
-    errno = EEXIST;
-  return fd;
-}
-
-#define mkstemp  homegrown_mkstemp
-#endif  /* !defined HAVE_MKSTEMP */
-
 void
 init_ephemstuff (void)
 {
@@ -99,35 +61,36 @@ jam_sff (struct sff *sff, const char *prefix)
    string for cwd.)  If no name is possible, signal a fatal
    error.  Also, set ‘sff->disposition’ to ‘real’.  */
 {
-#define tmpdir  EPH (tmpdir)
   char *fn;
   size_t len;
   int fd;
 
   if (!prefix)
     {
-      if (! tmpdir)
+      if (! EPH (standard))
         {
+          char const *dir = NULL;
           char slash[2] = { SLASH, '\0' };
 
 #define TRY(envvarname)                         \
-          if (! tmpdir)                         \
-            tmpdir = getenv (#envvarname)
+          if (! dir)                            \
+            dir = getenv (#envvarname)
           TRY (TMPDIR);                 /* Unix tradition */
           TRY (TMP);                    /* DOS tradition */
           TRY (TEMP);                   /* another DOS tradition */
 #undef TRY
-          if (! tmpdir)
-            tmpdir = P_tmpdir;
+          if (! dir)
+            dir = P_tmpdir;
 
-          accf (SHARED, "%s%s", tmpdir,
-                SLASH != tmpdir[strlen (tmpdir) - 1] ? slash : "");
-          tmpdir = finish_string (SHARED, &len);
+          accf (PLEXUS, "%s%s%s", dir,
+                SLASH != dir[strlen (dir) - 1] ? slash : "",
+                PROGRAM (name));
+          EPH (standard) = finish_string (PLEXUS, &len);
         }
-      prefix = tmpdir;
+      prefix = EPH (standard);
     }
-  accf (SHARED, "%sXXXXXX", prefix);
-  fn = finish_string (SHARED, &len);
+  accf (PLEXUS, "%sXXXXXX", prefix);
+  fn = finish_string (PLEXUS, &len);
   /* Support the 8.3 MS-DOG restriction, blech.  Truncate the non-directory
      filename component to two bytes so that the maximum non-extension name
      is 2 + 6 (Xs) = 8.  The extension is left empty.  What a waste.  */
@@ -149,13 +112,12 @@ jam_sff (struct sff *sff, const char *prefix)
         *dot = '0' + getpid () % 10;
     }
 
-  if (PROB (fd = mkstemp (fn)))
+  if (PROB (fd = fd_safer (mkstemp (fn))))
     PFATAL ("could not make temporary file name (template \"%s\")", fn);
 
   close (fd);
   sff->filename = fn;
   sff->disposition = real;
-#undef tmpdir
 }
 
 #define JAM_SFF(sff,prefix)  jam_sff (&sff, prefix)
