@@ -65,7 +65,6 @@ struct grok
 };
 
 #define STRUCTALLOC(to,type)  alloc (to, #type, sizeof (type))
-#define NEWPAIR(to)  STRUCTALLOC (to, struct link)
 
 #if CONTEXTUAL
 static void
@@ -286,12 +285,9 @@ static void
 start_atat (struct divvy *to, bool blankp)
 {
   struct obstack *o = to->space;
-  size_t uncool = 7 & (uintptr_t) obstack_next_free (o);
 
-  /* If the next alloc is not 64-bit (8-byte) aligned, do a dummy alloc.
-     Perhaps this should better be done, once, in ‘make_space’.  */
-  if (uncool)
-    obstack_alloc (o, 8 - uncool);
+  /* We used to check and ensure ‘off_t’ (8-byte) alignment here,
+     but that is now done in ‘make_space’ directly.  */
 
   if (blankp)
     obstack_blank (o, sizeof (struct atat));
@@ -508,6 +504,17 @@ gethash (char const *revno, struct hash *ht)
 }
 
 
+struct repo *
+empty_repo (struct divvy *to)
+{
+  struct repo *repo = zlloc (to, "repo", sizeof (struct repo));
+
+  repo->strict = STRICT_LOCKING;
+  repo->expand = -1;
+  repo->neck = -1;
+  return repo;
+}
+
 /* A nice prime of monolithic proportions.  */
 #define NSLOTS  149
 
@@ -521,8 +528,9 @@ full (struct divvy *to, struct fro *f)
   off_t neck;
   size_t count;
   struct link box, *tp;
+  struct wlink *follow;
   struct grok *g = FZLLOC (struct grok);
-  struct repo *repo = zlloc (to, "repo", sizeof (struct repo));
+  struct repo *repo = empty_repo (to);
 
   repo->ht = make_hash_table (to, NSLOTS);
 
@@ -645,7 +653,7 @@ full (struct divvy *to, struct fro *f)
          MAYBE_REVNO (g);
          count++)
       {
-        struct notyet *ny = STRUCTALLOC (g->tranquil, struct notyet);
+        struct notyet *ny = STRUCTALLOC (to, struct notyet);
         struct delta *d = ny->d = STRUCTALLOC (to, struct delta);
 
         STASH (d->num);
@@ -675,7 +683,7 @@ full (struct divvy *to, struct fro *f)
         SEMI (g, state);
 
         SYNCH (g, branches);
-        box.next = ny->branches, tp = &box;
+        box.next = NULL, tp = &box;
         while (MAYBE_REVNO (g))
           HANG (XREP (g).string);
         ny->branches = box.next;
@@ -684,6 +692,8 @@ full (struct divvy *to, struct fro *f)
         SYNCH (g, next);
         if (MAYBE_REVNO (g))
           STASH (ny->next);
+        else
+          ny->next = NULL;
         SEMI (g, next);
 
         if (probe_keyword (g, &TINY (commitid)))
@@ -693,6 +703,8 @@ full (struct divvy *to, struct fro *f)
             checkssym (d->commitid);
             SEMI (g, commitid);
           }
+        else
+          d->commitid = NULL;
 
         CEND ();
         wtp = wextend (wtp, ny, to);
@@ -735,7 +747,7 @@ full (struct divvy *to, struct fro *f)
     }
 
   CBEG ("edits");
-  for (size_t count = 0;
+  for (count = 0, follow = repo->deltas;
        (neck = fro_tello (g->from)) && count < repo->deltas_count;
        count++)
     {
@@ -748,6 +760,10 @@ full (struct divvy *to, struct fro *f)
       CBEG (revno);
       if (!(ny = FIND_NY (revno)))
         BUMMER ("found edits for %s `%s'", ks_ner, revno);
+      /* TODO: Instead of this (accumulate then reorder),
+         delay accumulation then accumulate in order.  */
+      follow->entry = ny;
+      follow = follow->next;
       d = ny->d;
       d->neck = neck;
       SYNCH (g, log);
