@@ -21,8 +21,6 @@
 */
 
 #include "config.h"
-#define _FILE_OFFSET_BITS 64
-
 #include <stdbool.h>
 #include <stdint.h>
 #include <stdio.h>
@@ -96,15 +94,9 @@ enum kwsub
 /* Main open flag for creating a lock file.  */
 #define OPEN_O_WRONLY O_WRONLY
 
-/* Is getlogin() secure?  Usually it's not.  */
-#define getlogin_is_secure 0
-
 /* Can ‘rename (A, B)’ falsely report success?  */
 #define bad_NFS_rename 0
 
-/* Does ‘setreuid’ work?  See top-level README.  */
-#define has_setreuid 0
-
 /* Might NFS be used?  */
 #define has_NFS 1
 
@@ -297,7 +289,9 @@ struct rcslock
   struct delta *delta;
 };
 
-/* List element for symbolic names.  */
+/* List element for symbolic names.
+   Also used for label/filename (merging)
+   and base/full (peer program names).  */
 struct symdef
 {
   char const *meaningful;
@@ -321,7 +315,7 @@ struct tinysym
 struct pool_found
 {
   int i;
-  struct tinysym *sym;
+  struct tinysym const *sym;
 };
 
 #define TINY(x)       (tiny_ ## x)
@@ -349,7 +343,7 @@ enum markers
 struct maybe;
 
 /* The function ‘pairnames’ takes to open the RCS file.  */
-typedef struct fro * (open_rcsfile_fn) (struct maybe *);
+typedef struct fro * (open_rcsfile_fn) (struct maybe *m);
 
 /* A combination of probe parameters and results for ‘pairnames’ through
    ‘fin2open’ through ‘finopen’ through {‘rcsreadopen’, ‘rcswriteopen’}
@@ -378,25 +372,25 @@ struct maybe
 };
 
 /* The locations of RCS programs, for internal use.  */
-extern const char const prog_co[];
-extern const char const prog_merge[];
-extern const char const prog_diff[];
-extern const char const prog_diff3[];
+extern char const prog_diff[];
+extern char const prog_diff3[];
 
 /* Flags to make diff(1) work with RCS.  These
    should be a single argument (no internal spaces).  */
-extern const char const diff_flags[];
+extern char const diff_flags[];
 
 /* A string of 77 '=' followed by '\n'.  */
-extern const char const equal_line[];
+extern char const equal_line[];
 
 /* Every program defines this.  */
 struct program
 {
+  /* The invocation filename, basically a copy of ‘argv[0]’.  */
+  char const *invoke;
   /* The name of the program, for --help, --version, etc.  */
-  const char const *name;
+  char const *name;
   /* Text for --help.  */
-  const char const *help;
+  char const *help;
   /* Exit errorfully.  */
   void (*exiterr) (void) exiting;
 };
@@ -416,6 +410,10 @@ struct sff
    Subsystems also communicate via these settings.  */
 struct behavior
 {
+  char const *invdir;
+  /* The directory portion of ‘PROGRAM (invoke)’.
+     -- find_peer_prog  */
+
   bool unbufferedp;
   /* Although standard error should be unbuffered by default,
      don't rely on it.
@@ -696,7 +694,7 @@ extern struct top *top;
 #define FLOW(member)  (top->flow. member)
 
 /* b-anchor */
-extern const char const ks_revno[];
+extern char const ks_revno[];
 extern TINY_DECL (ciklog);
 extern TINY_DECL (access);
 extern TINY_DECL (author);
@@ -721,13 +719,12 @@ extern TINY_DECL (text);
 bool looking_at (struct tinysym const *sym, char const *start);
 int recognize_kwsub (struct cbuf const *x);
 int str2expmode (char const *s);
-const char const *kwsub_string (enum kwsub i);
+char const *kwsub_string (enum kwsub i);
 bool recognize_keyword (char const *string, struct pool_found *found);
 
 /* merger */
 int merge (bool tostdout, char const *edarg,
-           char const *const label[3],
-           char const *const argv[3]);
+           struct symdef three_manifestations[3]);
 
 /* rcsedit */
 struct editstuff *make_editstuff (void);
@@ -794,10 +791,10 @@ void putdftext (struct delta const *delta, struct fro *finfile,
                 FILE *foutfile, bool diffmt);
 
 /* rcskeep */
-bool getoldkeys (struct fro *);
+bool getoldkeys (struct fro *fp);
 
 /* rcsmap */
-extern const enum tokens const ctab[];
+extern enum tokens const ctab[];
 char const *checkid (char const *id, int delimiter);
 char const *checksym (char const *sym, int delimiter);
 void checksid (char const *id);
@@ -833,6 +830,7 @@ void exit_failurefully (void)
 void exit_diff_trouble (void)
   exiting;
 void gnurcs_init (struct program const *program);
+void gnurcs_goodbye (void);
 void bad_option (char const *option);
 void redefined (int c);
 struct cbuf minus_p (char const *xrev, char const *rev);
@@ -876,7 +874,7 @@ int getRCSINIT (int argc, char **argv, char ***newargv);
 
 #define fully_numeric_no_k(cb,source)  fully_numeric (cb, source, NULL)
 
-#define TINYS(x)  ((char *)(x)->bytes)
+#define TINYS(x)  ((char const *)(x)->bytes)
 
 #define TINYKS(x)  TINYS (&TINY (x))
 
