@@ -89,22 +89,22 @@ exiterr (void)
   exit_failurefully ();
 }
 
-#define ACCF(...)  accf (SHARED, __VA_ARGS__)
+#define ACCF(...)  accf (PLEXUS, __VA_ARGS__)
 
-#define OK(x)     (x)->string = finish_string (SHARED, &((x)->size))
+#define OK(x)     (x)->string = finish_string (PLEXUS, &((x)->size))
 #define JAM(x,s)  do { ACCF ("%s", s); OK (x); } while (0)
 #define ADD(x,s)  do { ACCF ("%s", (x)->string); JAM (x, s); } while (0)
 
 static void
 incnum (char const *onum, struct cbuf *nnum)
 /* Increment the last field of revision number ‘onum’
-   by one into a ‘SHARED’ string and point ‘nnum’ at it.  */
+   by one into a ‘PLEXUS’ string and point ‘nnum’ at it.  */
 {
   register char *tp, *np;
   register size_t l;
 
   ACCF ("%s%c", onum, '\0');
-  np = finish_string (SHARED, &nnum->size);
+  np = finish_string (PLEXUS, &nnum->size);
   nnum->string = np;
   l = nnum->size - 1;
   for (tp = np + l; np != tp;)
@@ -165,19 +165,18 @@ removelock (struct delta *delta)
 
 static struct wlink newbranch;          /* new branch to be inserted */
 
-#define BHDELTA(x)  ((struct delta *)(x)->entry)
-
 static int
 addbranch (struct delta *branchpoint, struct cbuf *num, bool removedlock)
 /* Add a new branch and branch delta at ‘branchpoint’.
    If ‘num’ is the null string, append the new branch, incrementing
    the highest branch number (initially 1), and setting the level number to 1.
    The new delta and branchhead are in globals ‘newdelta’ and ‘newbranch’, resp.
-   The new number is placed into a ‘SHARED’ string with ‘num’ pointing to it.
+   The new number is placed into a ‘PLEXUS’ string with ‘num’ pointing to it.
    Return -1 on error, 1 if a lock is removed, 0 otherwise.
    If ‘removedlock’, a lock was already removed.  */
 {
   struct wlink **btrail;
+  struct delta *d;
   int result;
   int field, numlength;
 
@@ -205,7 +204,8 @@ addbranch (struct delta *branchpoint, struct cbuf *num, bool removedlock)
       while (bhead->next)
         bhead = bhead->next;
       bhead->next = &newbranch;
-      incnum (BRANCHNO (BHDELTA (bhead)->num), num);
+      d = bhead->entry;
+      incnum (BRANCHNO (d->num), num);
       ADD (num, ".1");
       newbranch.next = NULL;
     }
@@ -215,8 +215,8 @@ addbranch (struct delta *branchpoint, struct cbuf *num, bool removedlock)
       field = numlength - ((numlength & 1) ^ 1);
       /* Field of branch number.  */
       btrail = &branchpoint->branches;
-      while (0 < (result = cmpnumfld (num->string, BHDELTA (*btrail)->num,
-                                      field)))
+      while (d = (*btrail)->entry,
+             0 < (result = cmpnumfld (num->string, d->num, field)))
         {
           btrail = &(*btrail)->next;
           if (!*btrail)
@@ -276,7 +276,7 @@ addelta (struct wlink **tp_deltas)
   int removedlock;
   int newdnumlength;            /* actual length of new rev. num. */
   struct delta *tip = REPO (tip);
-  char const *defbr = REPO (r) ? GROK (branch) : NULL;
+  char const *defbr = GROK (branch);
 
   newdnumlength = countnumflds (newdelnum.string);
 
@@ -443,9 +443,7 @@ fixwork (mode_t newworkmode, time_t mtime)
     || (newworkmode & S_IWUSR && !stat_mine_p (&workstat))
     || PROB (setmtime (mani_filename, mtime))
     ? -1 : workstat.st_mode == newworkmode ? 0
-#ifdef HAVE_FCHMOD
-    : !PROB (fchmod (workptr->fd, newworkmode)) ? 0
-#endif
+    : !PROB (change_mode (workptr->fd, newworkmode)) ? 0
     : chmod (mani_filename, newworkmode)
     ;
 }
@@ -484,6 +482,7 @@ xpandfile (struct fro *unexfile, struct delta const *delta,
           if (e <= 1)
             break;
         }
+      FINISH_EXPCTX (&ctx);
     }
   *exname = targetname;
   return r & 1;
@@ -632,6 +631,7 @@ main (int argc, char **argv)
   struct wlink *deltas;                 /* Deltas to be generated.  */
   const struct program program =
     {
+      .invoke = argv[0],
       .name = "ci",
       .help = help,
       .exiterr = exiterr
@@ -650,11 +650,6 @@ main (int argc, char **argv)
   usestatdate = false;
   BE (pe) = X_DEFAULT;
 
-  /* Workaround a x86_64-linux-gnu problem.  Removing this (deferring
-     the call to only when it's needed) results in corrupted memory,
-     ending up with a segfault.  TODO: Debug further.  */
-  getcurdate ();
-
   argc = getRCSINIT (argc, argv, &newargv);
   argv = newargv;
   while (a = *++argv, 0 < --argc && *a++ == '-')
@@ -731,7 +726,7 @@ main (int argc, char **argv)
             ud = ZLLOC (1, struct u_symdef);
             ud->override = ('N' == option);
             ud->u.meaningful = a;
-            tp_assoc = extend (tp_assoc, ud, SHARED);
+            tp_assoc = extend (tp_assoc, ud, PLEXUS);
           }
           break;
 
@@ -1064,28 +1059,17 @@ main (int argc, char **argv)
                 int wfd = workptr->fd;
                 struct stat checkworkstat;
                 char const *diffv[6 + !!OPEN_O_BINARY], **diffp;
-                off_t wo;
 
                 diagnose ("new revision: %s; previous revision: %s",
                           newdelta.num, targetdelta->num);
                 SAME_AFTER (from, targetdelta->text);
                 newdelta.pretty_log = getlogmsg ();
-                if (STDIO_P (workptr))
-                  {
-                    bool badness = false;
 
-                    fro_bob (workptr);
-                    if (CAN_FFLUSH_IN)
-                      badness = PROB (fflush (workptr->stream));
-                    else
-                      {
-                        wo = lseek (wfd, 0, SEEK_CUR);
-                        badness = (-1 == wo
-                                   || (wo && PROB (lseek (wfd, 0, SEEK_SET))));
-                      }
-                    if (badness)
-                      Ierror ();
-                  }
+                /* "Rewind" ‘workptr’ before feeding it to diff(1).  */
+                fro_bob (workptr);
+                if (PROB (lseek (wfd, 0, SEEK_SET)))
+                  Ierror ();
+
                 diffp = diffv;
                 *++diffp = prog_diff;
                 *++diffp = diff_flags;
@@ -1098,10 +1082,6 @@ main (int argc, char **argv)
                 *++diffp = NULL;
                 if (DIFF_TROUBLE == runv (wfd, diffname, diffv))
                   RFATAL ("diff failed");
-                if (STDIO_P (workptr)
-                    && !CAN_FFLUSH_IN
-                    && PROB (lseek (wfd, wo, SEEK_CUR)))
-                  Ierror ();
                 if (newhead)
                   {
                     fro_bob (workptr);
@@ -1197,6 +1177,7 @@ main (int argc, char **argv)
       }
 
   tempunlink ();
+  gnurcs_goodbye ();
   return exitstatus;
 }
 
