@@ -21,6 +21,10 @@
 
 struct maketimestuff
 {
+  bool tzset_called_p;
+  /* True if we have already called ‘tzset’.
+     -- local_tm  */
+
   char const *TZ;
   /* The value of env var ‘TZ’.
      Only valid/used if ‘TZ_must_be_set’.
@@ -33,14 +37,15 @@ struct maketimestuff
   time_t t_cache[2];
   struct tm tm_cache[2];
   /* Cache the most recent ‘t’,‘tm’ pairs;
-     One for ‘gmtime_r’, one for ‘localtime_r’.
+     [0] for UTC, [1] for local time.
      -- tm2time  */
 };
 
-struct tm *time2tm (time_t, bool);
-time_t difftm (struct tm const *, struct tm const *);
-time_t str2time (char const *, time_t, long);
-time_t tm2time (struct tm *, bool);
-void adjzone (struct tm *, long);
+struct tm *local_tm (const time_t *timep, struct tm *result);
+struct tm *time2tm (time_t unixtime, bool localzone);
+time_t difftm (struct tm const *a, struct tm const *b);
+time_t str2time (char const *source, time_t default_time, long default_zone);
+time_t tm2time (struct tm *tm, bool localzone);
+void adjzone (struct tm *t, long seconds);
 
 /* maketime.h ends here */
