@@ -132,7 +132,7 @@ getassoclst (struct link **tp, char *sp)
       SKIPWS ();
       ud->u.underlying = sp;
     }
-  *tp = extend (*tp, ud, SHARED);
+  *tp = extend (*tp, ud, PLEXUS);
 
 #undef SKIPWS
 }
@@ -145,7 +145,7 @@ getchaccess (struct link **tp, char const *login, enum changeaccess command)
   ch = ZLLOC (1, struct chaccess);
   ch->login = login;
   ch->command = command;
-  *tp = extend (*tp, ch, SHARED);
+  *tp = extend (*tp, ch, PLEXUS);
 }
 
 static void
@@ -203,7 +203,7 @@ getmessage (struct link **tp, char *option)
   um = ZLLOC (1, struct u_log);
   um->revno = option;
   um->message = cb;
-  *tp = extend (*tp, um, SHARED);
+  *tp = extend (*tp, um, PLEXUS);
 }
 
 static void
@@ -243,7 +243,7 @@ getstates (struct link **tp, char *sp)
   us = ZLLOC (1, struct u_state);
   us->status = temp;
   us->revno = sp;
-  *tp = extend (*tp, us, SHARED);
+  *tp = extend (*tp, us, PLEXUS);
 }
 
 static void
@@ -820,6 +820,7 @@ dolocks (void)
   struct link const *lockpt;
   struct delta *target, *tip = REPO (tip);
   bool changed = false;
+  const char *bye;
 
   if (unlockcaller)
     {
@@ -859,15 +860,14 @@ dolocks (void)
 
   /* Remove locks which are stored in rmvlocklst.  */
   for (lockpt = rmvlocklst; lockpt; lockpt = lockpt->next)
-    if (fully_numeric_no_k (&numrev, lockpt->entry))
+    if (fully_numeric_no_k (&numrev, (bye = lockpt->entry)))
       {
         target = delta_from_ref (numrev.string);
         if (target)
           {
             if (!(countnumflds (numrev.string) & 1)
                 && !NUM_EQ (target->num, numrev.string))
-              RERR ("can't unlock nonexisting revision %s",
-                    (char const *) lockpt->entry);
+              RERR ("can't unlock nonexisting revision %s", bye);
             else
               changed |= breaklock (target);
           }
@@ -1111,6 +1111,7 @@ main (int argc, char **argv)
   struct wlink *deltas;
   const struct program program =
     {
+      .invoke = argv[0],
       .name = "rcs",
       .help = help,
       .exiterr = exiterr
@@ -1204,7 +1205,7 @@ main (int argc, char **argv)
               lockhead = true;
               break;
             }
-          tplock = extend (tplock, a, SHARED);
+          tplock = extend (tplock, a, PLEXUS);
           break;
 
         case 'u':
@@ -1214,7 +1215,7 @@ main (int argc, char **argv)
               unlockcaller = true;
               break;
             }
-          tprm = extend (tprm, a, SHARED);
+          tprm = extend (tprm, a, PLEXUS);
           newlocklst = boxlock.next;
           tplock = rmnewlocklst (a);
           break;
@@ -1389,7 +1390,7 @@ main (int argc, char **argv)
            for the RCS file.  The admin node is initialized.  */
         repo_stat = &REPO (stat);
         tip = REPO (tip);
-        defbr = REPO (r) ? GROK (branch) : NULL;
+        defbr = GROK (branch);
         diagnose ("RCS file: %s", REPO (filename));
 
         changed = initflag | textflag;
@@ -1519,7 +1520,7 @@ main (int argc, char **argv)
                 unmake_editstuff (es);
                 IGNORE_REST (from);
               }
-            else if (REPO (r))
+            else if (GROK (desc))
               SAME_AFTER (FLOW (from), GROK (desc));
           }
 
@@ -1548,6 +1549,7 @@ main (int argc, char **argv)
       }
 
   tempunlink ();
+  gnurcs_goodbye ();
   return exitstatus;
 }
 
