@@ -28,6 +28,7 @@
 #include "b-divvy.h"
 #include "b-feph.h"
 #include "b-fro.h"
+#include "b-peer.h"
 
 struct top *top;
 
@@ -106,10 +107,10 @@ setup_label (char const *num, char const date[datesize])
   char datestr[datesize + zonelenmax];
 
   date2str (date, datestr);
-  accf (SHARED, "-L%s\t%s", MANI (filename), datestr);
+  accf (PLEXUS, "-L%s\t%s", MANI (filename), datestr);
   if (num)
-    accf (SHARED, "\t%s", num);
-  return finish_string (SHARED, &len);
+    accf (PLEXUS, "\t%s", num);
+  return finish_string (PLEXUS, &len);
 }
 #endif
 
@@ -160,6 +161,7 @@ main (int argc, char **argv)
   register int c;
   const struct program program =
     {
+      .invoke = argv[0],
       .name = "rcsdiff",
       .help = help,
       .exiterr = exiterr
@@ -181,7 +183,7 @@ main (int argc, char **argv)
 
   /* Room for runv extra + args [+ --binary] [+ 2 labels]
      + 1 file + 1 trailing null.  */
-  diffv = pointer_array (SHARED, (1 + argc
+  diffv = pointer_array (PLEXUS, (1 + argc
                                   + !!OPEN_O_BINARY
                                   + 2 * DIFF_L + 2));
   diffp = diffv + 1;
@@ -312,8 +314,8 @@ main (int argc, char **argv)
       size_t len;
 
       for (pp = diffv + 2; pp < diffp;)
-        accf (SHARED, " %s", *pp++);
-      diffvstr = finish_string (SHARED, &len);
+        accf (PLEXUS, " %s", *pp++);
+      diffvstr = finish_string (PLEXUS, &len);
     }
 
 #if DIFF_L
@@ -327,7 +329,7 @@ main (int argc, char **argv)
 #endif
   diffpend = diffp;
 
-  cov[1] = prog_co;
+  cov[1] = PEER_CO ();
   cov[2] = "-q";
 #if !DIFF_L
   cov[3] = "-M";
@@ -448,7 +450,7 @@ main (int argc, char **argv)
             diffp[1] = mani_filename;
             if (*mani_filename == '-')
               {
-                accf (SHARED, ".%c", SLASH);
+                accf (PLEXUS, ".%c", SLASH);
                 diffp[1] = str_save (mani_filename);
               }
           }
@@ -481,6 +483,7 @@ main (int argc, char **argv)
       }
 
   tempunlink ();
+  gnurcs_goodbye ();
   return exitstatus;
 }
 
