@@ -96,6 +96,7 @@ scandeltatext (struct editstuff *es, struct wlink **ls,
           afputc (c, to);
         while (1 < expandline (&ctx))
           continue;
+        FINISH_EXPCTX (&ctx);
       }
       break;
     case edit:
@@ -290,11 +291,11 @@ putdesc (struct cbuf *cb, bool textflag, char *textfile)
                       if (feof (txt))
                         break;
                     }
-                  accumulate_byte (SHARED, c);
+                  accumulate_byte (PLEXUS, c);
                 }
               if (PROB (fclose (txt)))
                 Ierror ();
-              p = finish_string (SHARED, &s);
+              p = finish_string (PLEXUS, &s);
             }
           *cb = cleanlogmsg (p, s);
         }
@@ -337,9 +338,9 @@ getsstdin (char const *option, char const *name, char const *note)
         }
       else
         column++;
-      accumulate_byte (SHARED, c);
+      accumulate_byte (PLEXUS, c);
     }
-  p = finish_string (SHARED, &len);
+  p = finish_string (PLEXUS, &len);
 #undef prompt
   return cleanlogmsg (p, len - (discardp ? 1 : 0));
 }
@@ -347,8 +348,6 @@ getsstdin (char const *option, char const *name, char const *note)
 void
 format_assocs (FILE *out, char const *fmt)
 {
-  if (! REPO (r))
-    return;
   for (struct link *ls = GROK (symbols); ls; ls = ls->next)
     {
       struct symdef const *d = ls->entry;
@@ -401,7 +400,7 @@ putadmin (void)
 
   aputs (TINYKS (access), fout);
   for (struct link *ls = r ? GROK (access) : NULL; ls; ls = ls->next)
-    aprintf (fout, "\n\t%s", (char *) ls->entry);
+    aprintf (fout, "\n\t%s", (char const *) ls->entry);
   aprintf (fout, ";\n%s", TINYKS (symbols));
   format_assocs (fout, "\n\t%s:%s");
   aprintf (fout, ";\n%s", TINYKS (locks));
@@ -419,6 +418,7 @@ putadmin (void)
   if (kws != kwsub_kv)
     aprintf (fout, "%s\t%c%s%c;\n",
              TINYKS (expand), SDELIM, kwsub_string (kws), SDELIM);
+  aprintf (fout, "\n");
 }
 
 static void
