@@ -27,6 +27,8 @@
 #include "b-divvy.h"
 #include "b-feph.h"
 #include "b-fro.h"
+#include "b-merger.h"
+#include "b-peer.h"
 
 struct top *top;
 
@@ -62,15 +64,16 @@ main (int argc, char **argv)
 {
   register int i;
   char *a, **newargv;
-  char const *arg[3];
-  char const *rev[3], *xrev[3];         /*revision numbers */
+  struct symdef three_manifestations[3];
+  char const *rev[3];                   /*revision numbers */
   char const *edarg, *expandarg, *suffixarg, *versionarg, *zonearg;
   bool tostdout;
-  int status;
+  int status, exitstatus;
   struct fro *workptr;
   struct delta *target;
   const struct program program =
     {
+      .invoke = argv[0],
       .name = "rcsmerge",
       .help = help,
       .exiterr = exiterr
@@ -161,7 +164,7 @@ main (int argc, char **argv)
           struct cbuf numericrev;
           char const *repo_filename = REPO (filename);
           char const *mani_filename = MANI (filename);
-          char const *defbr = REPO (r) ? GROK (branch) : NULL;
+          char const *defbr = GROK (branch);
           struct delta *tip = REPO (tip);
 
           if (argc > 2 || (argc == 2 && argv[1]))
@@ -180,15 +183,15 @@ main (int argc, char **argv)
           if (fully_numeric (&numericrev, rev[1], workptr)
               && (target = delta_from_ref (numericrev.string)))
             {
-              xrev[1] = target->num;
+              LABEL (1) = target->num;
               if (!rev[2] || !*rev[2])
                 rev[2] = defbr ? defbr : tip->num;
               if (fully_numeric (&numericrev, rev[2], workptr)
                   && (target = delta_from_ref (numericrev.string)))
                 {
-                  xrev[2] = target->num;
+                  LABEL (2) = target->num;
 
-                  if (STR_SAME (xrev[1], xrev[2]))
+                  if (STR_SAME (LABEL (1), LABEL (2)))
                     {
                       if (tostdout)
                         {
@@ -202,23 +205,23 @@ main (int argc, char **argv)
 
                       for (i = 1; i <= 2; i++)
                         {
-                          struct cbuf commarg = minus_p (xrev[i], rev[i]);
+                          struct cbuf commarg = minus_p (LABEL (i), rev[i]);
 
                           if (run (-1,
                                    /* Don't collide with merger.c ‘maketemp’.  */
-                                   arg[i] = maketemp (i + 2),
-                                   prog_co, quietarg, commarg.string,
+                                   FNAME (i) = maketemp (i + 2),
+                                   PEER_CO (), quietarg, commarg.string,
                                    expandarg, suffixarg, versionarg, zonearg,
                                    repo_filename, NULL))
                             RFATAL ("co failed");
                         }
                       diagnose
                         ("Merging differences between %s and %s into %s%s",
-                         xrev[1], xrev[2], mani_filename,
+                         LABEL (1), LABEL (2), mani_filename,
                          tostdout ? "; result to stdout" : "");
 
-                      arg[0] = xrev[0] = mani_filename;
-                      status = merge (tostdout, edarg, xrev, arg);
+                      FNAME (0) = LABEL (0) = mani_filename;
+                      status = merge (tostdout, edarg, three_manifestations);
                     }
                 }
             }
@@ -227,7 +230,9 @@ main (int argc, char **argv)
         }
     }
   tempunlink ();
-  return FLOW (erroneousp) ? DIFF_TROUBLE : status;
+  exitstatus = FLOW (erroneousp) ? DIFF_TROUBLE : status;
+  gnurcs_goodbye ();
+  return exitstatus;
 }
 
 /* rcsmerge.c ends here */
