@@ -54,7 +54,7 @@ exit_diff_trouble (void)
 void
 gnurcs_init (struct program const *program)
 {
-  SHARED = make_space ("shared");
+  PLEXUS = make_space ("plexus");
   SINGLE = make_space ("single");
   top = ZLLOC (1, struct top);
   unbuffer_standard_error ();
@@ -76,7 +76,7 @@ gnurcs_init (struct program const *program)
                       ? v
                       : NULL)
       /* Clamp user-specified value to [0,LONG_MAX].  */
-      ? (0 > (lim = atol (v))
+      ? (0 > (lim = strtol (v, NULL, 10))
          ? 0
          : lim)
       /* Default value.  */
@@ -84,6 +84,15 @@ gnurcs_init (struct program const *program)
   }
 }
 
+void
+gnurcs_goodbye (void)
+{
+  /* Whatever globals ‘gnurcs_init’ sets, we must reset.  */
+  top = NULL;
+  close_space (SINGLE); SINGLE = NULL;
+  close_space (PLEXUS); PLEXUS = NULL;
+}
+
 void
 bad_option (char const *option)
 {
@@ -189,7 +198,7 @@ char *
 str_save (char const *s)
 /* Save ‘s’ in permanently allocated storage.  */
 {
-  return intern (SHARED, s, strlen (s));
+  return intern (PLEXUS, s, strlen (s));
 }
 
 char *
@@ -258,8 +267,6 @@ accumulate_arg_quoted (struct divvy *space, int c, register char const *s)
 
 #endif  /* !defined HAVE_WORKING_FORK */
 
-#define exec_RCS execv
-
 int
 runv (int infd, char const *outname, char const **args)
 /* Run a command.
@@ -269,16 +276,11 @@ runv (int infd, char const *outname, char const **args)
 {
   int wstatus;
 
-#if BAD_WAIT_IF_SIGCHLD_IGNORED
   if (!BE (fixed_SIGCHLD))
     {
       BE (fixed_SIGCHLD) = true;
-#ifndef SIGCHLD
-#define SIGCHLD SIGCLD
-#endif
-      signal (SIGCHLD, SIG_DFL);
+      maybe_reset_sigchld ();
     }
-#endif  /* BAD_WAIT_IF_SIGCHLD_IGNORED */
 
   oflush ();
   {
@@ -306,7 +308,7 @@ runv (int infd, char const *outname, char const **args)
               complain ("%s: %s: cannot create\n", args[1], outname);
               exit_diff_trouble ();
             }
-        exec_RCS (args[1], (char **) (args + 1));
+        execv (args[1], (char **) (args + 1));
         notfound = args[1];
 #ifdef RCS_SHELL
         if (errno == ENOEXEC)
@@ -322,21 +324,8 @@ runv (int infd, char const *outname, char const **args)
       }
     if (PROB (pid))
       fatal_sys ("fork");
-#if defined HAVE_WAITPID
     if (PROB (waitpid (pid, &wstatus, 0)))
       fatal_sys ("waitpid");
-#else  /* !defined HAVE_WAITPID */
-    {
-      pid_t w;
-
-      do
-        {
-          if (PROB (w = wait (&wstatus)))
-            fatal_sys ("wait");
-        }
-      while (w != pid);
-    }
-#endif  /* !defined HAVE_WAITPID */
 #else   /* !defined HAVE_WORKING_FORK */
     size_t len;
     char *cmd;
@@ -344,15 +333,15 @@ runv (int infd, char const *outname, char const **args)
 
     /* Use ‘system’.  On many hosts ‘system’ discards signals.  Yuck!  */
     p = args + 1;
-    accs (SHARED, *p);
+    accs (PLEXUS, *p);
     while (*++p)
-      accumulate_arg_quoted (SHARED, ' ', *p);
+      accumulate_arg_quoted (PLEXUS, ' ', *p);
     if (infd != -1 && infd != STDIN_FILENO)
-      accf (SHARED, "<&%d", infd);
+      accf (PLEXUS, "<&%d", infd);
     if (outname)
-      accumulate_arg_quoted (SHARED, '>', outname);
-    wstatus = system (cmd = finish_string (SHARED, &len));
-    brush_off (SHARED, cmd);
+      accumulate_arg_quoted (PLEXUS, '>', outname);
+    wstatus = system (cmd = finish_string (PLEXUS, &len));
+    brush_off (PLEXUS, cmd);
 #endif  /* !defined HAVE_WORKING_FORK */
   }
   if (!WIFEXITED (wstatus))
@@ -412,7 +401,7 @@ setRCSversion (char const *str)
   else
     {
       display_version (top->program);   /* TODO:ZONK */
-      exit (0);
+      exit (EXIT_SUCCESS);
     }
 }
 
@@ -451,7 +440,7 @@ getRCSINIT (int argc, char **argv, char ***newargv)
             }
           break;
         }
-      *newargv = pp = pointer_array (SHARED, n);
+      *newargv = pp = pointer_array (PLEXUS, n);
       /* Copy program name.  */
       *pp++ = *argv++;
       for (p = q;;)
